@@ -62,8 +62,10 @@ from navinfo_tool.utils import (
     get_bracketed_content,    # 获取文本中所有小括号中的内容组成的list
     rm_bracketed,    # 去除文本中的括号，包括括号中的内容
     rm_symbol,    # 去除文本中的所有符号
-    read_csv,    # 读取csv文件
+    read_csv,    # 读取csv文件， 可以返回为list或者dict，通过isdict=True设置
+    write_csv,  # 将数组的内容写到csv中, 支持list或者dict两种数据格式
+    read_excel,    # 读取excel文件，可以返回为list或者dict，通过isdict=True设置
     write_json,    # 将json数据写到json文件中，解决了一些数据类型报错问题
-    write2csv    # 将数组的内容写到csv中
+    write_excel    # 将数组的内容写到excel中, 支持list或者dict两种数据格式
 
 )
\ No newline at end of file
